@@ -1,4 +1,8 @@
-# Produced by 'meteoalarm-tools' @'2021-01-29UTC18:31'
+#                WARNING
+# THIS FILE WAS PRODUCED BY TOOLS THAT AUTOMATICALLY
+# PULL THE RELEVANT INFORMATION FROM meteoalarm.eu
+# DON'T EDIT IT MANUALLY!
+# Produced by 'meteoalarm-tools'@'2021-02-05UTC12:25'
 
 regions = {
     "AT": {
@@ -1984,15 +1988,15 @@ regions = {
 "East Midlands":"011",
 "East of England":"012",
 "Grampian":"015",
-"Highland & Islands":"002",
-"London & South East":"013",
-"Lothian & Borders":"004",
+"Highland &amp; Islands":"002",
+"London &amp; South East":"013",
+"Lothian &amp; Borders":"004",
 "North East":"007",
 "North West":"009",
 "Northern Ireland":"014",
 "South West":"001",
 "Strathclyde":"005",
-"Tayside, Central & Fife":"003",
+"Tayside, Central &amp; Fife":"003",
 "Wales":"016",
 "West Midlands":"010",
 "Yorkshire and the Humber":"008",
@@ -2057,7 +2061,7 @@ countries = {
     "IT": ("IT-Italy", "italiano,english"),
     "LT": ("LT-Lithuania", "lietuviu"),
     "LU": ("LU-Luxembourg", "français,deutsch,english"),
-    "LV": ("LV-Latvia", "latviešu"),
+    "LV": ("LV-Latvia", "english,latviešu"),
     "MD": ("MD-Moldova", ""),
     "ME": ("ME-Montenegro", "english,Црногорски"),
     "MK": ("MK-Republic%20of%20North%20Macedonia", ""),
@@ -2073,3 +2077,9 @@ countries = {
     "SK": ("SK-Slovakia", "slovenčina,english"),
     "UK": ("UK-United%20Kingdom", ""),
 }
+
+
+awl_to_num = {v[0]: int(k) for k, v in awl.items()}
+awareness_levels = tuple(awl.values())
+awareness_types = tuple(awt.values())
+countries_list = tuple(countries.keys())
